@@ -146,7 +146,7 @@ def line(x1: int, y1: int, x2: int, y2: int, **kwargs):
     arrow_end = kwargs.get("arrow_end", False)
     command = kwargs.get("command", None)
     name = kwargs.get("name", None)
-    if fill_mouse_on is not None and in_line(*processing.mouseXY(), *points[0],*points[1]):
+    if fill_mouse_on is not None and in_line(*processing.mouseXY(), *points[0], *points[1]):
         if processing.mouse_click_down() and command is not None:
             if name is not None:
                 command(name)
@@ -310,8 +310,9 @@ def polygone(points: list, **kwargs):
     stroke_weight = kwargs.get("stroke_weight", processing.__border_width)
     fill_mouse_on = kwargs.get("fill_mouse_on", processing.__fill_color_mouse_on)
     no_stroke = kwargs.get("no_stroke", False)
-    command =kwargs.get("command", None)
+    command = kwargs.get("command", None)
     name = kwargs.get("name", None)
+    click_up = kwargs.get("click_up", False)
     if no_stroke is True:
         stroke_weight = 0
     if isinstance(fill, str):
@@ -326,7 +327,8 @@ def polygone(points: list, **kwargs):
                                 points)
         else:
             if processing.in_polygone(*processing.mouseXY(), points):
-                if processing.mouse_click_down() and command is not None:
+                if ((not click_up and processing.mouse_click_down()) or (
+                        click_up and processing.mouse_click_up())) and command is not None:
                     if name is not None:
                         command(name)
                     else:
