@@ -8,7 +8,10 @@ Image = pygame.Surface
 
 def loadImage(fichier: str) -> Image:
     """retourne une surface de type image"""
-    return pygame.image.load(fichier)
+    try:
+        return pygame.image.load(fichier)
+    except:
+        FileNotFoundError(fichier)
 
 
 def image(picture, x, y):
